### ===================================================================================================================
###                                                       VIIA
###                                             Objectnr: Based on 1017A
###                                           Structural engineer: Example
### ===================================================================================================================
# TEMPLATE MODELSCRIPT v4.0
# Copyright VIIA

# =====================================================================================================================
#                                                    INITIAL SETUP
# =====================================================================================================================
# Import other functionality
from math import pi, sqrt

# Import the viiaPackage
from viiapackage import *


# Set up the project information
project = viia_create_project(project_name='1017A', version_nr=1)

# Toggle plots
show = False
# =====================================================================================================================
#                                                     SETUP GRID
# =====================================================================================================================

# Create the main grid with tags exterior and interior
x_grid = [0, 4.4, 6.7, 9.4, 12.1, 15.8, 17.9, 35.1]
y_grid = [0, 1.3, 2.1, 3.7, 4.9, 8.1, 11.4, 16.4]
grid = project.viia_create_orthogonal_grid([[x_grid, y_grid]], name='Main Grid')

# Create a separate grid for the barn columns
x_col_grid = [11.1, 15.9, 19.8, 23.7, 28.1, 32.8]
y_col_grid = [5.0, 6.1, 11.4]
column_grid = project.viia_create_orthogonal_grid([[x_col_grid, y_col_grid]], name='Column Grid')

# Create grid for upper collar ties in barn roof
x_collar_ties = [6.73 + i * 0.58 for i in range(43)]
y_collar_ties = [0, 16.48]
collar_tie_grid = project.viia_create_orthogonal_grid([[x_collar_ties, y_collar_ties]], name='Upper collar tie grid')

# Create grid for rafters and collar ties in house roof
x_house_roof = [0, 1.6, 3.3, 5.0, 6.7]
y_house_roof = [3.7, 11.4]
house_roof_grid = project.viia_create_orthogonal_grid([[x_house_roof, y_house_roof]], name='House roof beam grid')

# Generate pile coordinates
pile_coordinates_side = [[x, grid['8']] for x in [6.73 + i * 0.75 for i in range(38)]]
pile_coordinates_front = [[grid['C'], y] for y in [11.43 + i * 0.6 for i in range(9)]]

# Create the levels
project.viia_create_levels([-0.5, 0, 2.0, 3.0, 5.3, 7.5])

# Plot the grids
project.viia_plot_grid(show=show)

# =====================================================================================================================
#                                              LAYER N0 (GROUND FLOOR)
# =====================================================================================================================
"""Step 4: Create Geometry"""

# Walls
n0_wall_list = [
    ['H1', 'H7', 'MW-KLEI<1945', 210],
    ['H7', 'H8', 'MW-KLEI<1945', 210],
    ['C8', 'H8', 'MW-KLEI>1945', 100],
    ['C7', 'C8', 'MW-KLEI>1945', 210],
    ['C2', 'C7', 'MW-KLEI<1945', 210],
    ['C2', 'D2', 'MW-KLEI<1945', 210],
    ['D2', 'F2', 'MW-KLEI<1945', 100],
    ['F1', 'F2', 'MW-KLEI<1945', 210],
    ['A7', 'C7', 'MW-KLEI<1945', 100],
    ['A4', 'A7', 'MW-KLEI<1945', 100],
    ['A4', 'C4', 'MW-KLEI<1945', 100],
    ['A6', 'C6', 'MW-KLEI<1945', 100],
    ['B4', 'B6', 'MW-KLEI<1945', 100],
    ['E2', 'E6', 'MW-KLEI<1945', 100],
    ['E5', 'G5', 'MW-KLEI<1945', 100],
    ['F2', 'F6', 'MW-KLEI<1945', 100],
    ['F3', 'G3', 'MW-KLEI<1945', 100],
    ['G1', 'G3', 'MW-KLEI<1945', 100],
    ['G3', 'G5', 'MW-KLEI<1945', 100],
    ['G5', 'G6', 'MW-KLEI<1945', 100],
    ['C6', 'G6', 'MW-KLEI<1945', 100],
    ['F1', 'H1', 'MW-KLEI<1945', 100]]
n0_walls = project.viia_create_walls_on_grid(layer='N0', z_bottom=grid['L2'], z_top=grid['L4'], wall_list=n0_wall_list)

# Floors
n0_floor_list = [
    ['B4', 'C4', 'C6', 'B6', 'LIN-BETON', 110]]
n0_floors = project.viia_create_floors_on_grid(layer='N0', z_coordinate=grid['L2'], floor_list=n0_floor_list)

# Columns
# Foundation columns in the barn underneath the columns supporting the roofs
n0_column_list = [['A2', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
                  ['B1', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
                  ['C1', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
                  ['D1', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
                  ['E1', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
                  ['F1', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
                  ['A3', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
                  ['B3', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
                  ['C3', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
                  ['D3', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
                  ['E3', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
                  ['F3', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600']]
n0_columns = project.viia_create_columns_on_grid(layer='N0', column_list=n0_column_list, grid=column_grid)

"""Step 5: Structural Schematisation"""

# Plot layer in 3D
project.viia_plot_layers(layers='N0', view='3D', show=show)

# Plot with names of wall-shapes
project.viia_plot_layers(layers='N0', view='2D', shape_types='walls', show=show)

"""Step 6: Edit Geometry"""

# Adding openings to surface shapes
n0_wall_opening_list = [
    ['wall_1', [[1.346, 0.552, 1.359, 0.805],
                [0.975, 1.979, 0, 2.3392],
                [0.990, 0.552, 1.359, 0.805],
                [1.432, 0.552, 1.359, 0.805],
                [1.432, 0.552, 1.359, 0.805]]],
    ['wall_2', [[0, 3.022, 0, grid['L3']],
                [0.611, 0.552, 1.359, 0.805]]],
    ['wall_3', [[2.390, 0.406, 1.030, 0.562],
                [4.403, 0.406, 1.030, 0.562],
                [4.401, 0.406, 1.030, 0.562],
                [4.401, 0.406, 1.030, 0.562],
                [4.390, 0.406, 1.030, 0.562],
                [4.401, 0.406, 1.030, 0.562]]],
    ['wall_6', [[0.705, 1.036, 0.504, 1.752]]],
    ['wall_7', [[0, 1.036, 0.504, 1.752],
                [1.898, 1.806, 1.133, 1.115],
                [0.546, 1.040 + 0.069, 0, 2.153]]],
    ['wall_9', [[0.807, 1.509, 1.320, 0.917],
                [2.286, 1.500, 1.311, 0.917]]],
    ['wall_10', [[0.999, 2.283, 0.713, 1.531],
                 [1.528, 2.277, 0.689, 1.531]]],
    ['wall_11', [[1.017, 1.781, 0.713, 1.543],
                 [2.157, 1.534, 0, 2.285]]],
    ['wall_12', [[1.300, 0.880, 0.0, 2.179]]],
    ['wall_13', [[1.435, 0.880, 0.0, 2.169]]],
    ['wall_14', [[2.666, 0.933, 0.0, 2.161]]],
    ['wall_15', [[0.924, 0.920, 0.0, 2.162],
                 [2.141, 0.889, 0.0, 2.161]]],
    ['wall_16', [[2.175, 0.910, 0.0, 2.142]]],
    ['wall_17', [[0.954, 0.881, 0.0, 2.064]]]]
project.viia_add_openings(opening_data_list=n0_wall_opening_list)

# =====================================================================================================================
#                                                      LAYER N1
# =====================================================================================================================
"""Step 4: Create Geometry"""

# Walls
n1_wall_list = [
    ['C2', 'C8', 'MW-KLEI<1945', 210],
    ['A4', 'A7', 'MW-KLEI<1945', 100]]
n1_walls = project.viia_create_walls_on_grid('N1', grid['L4'], grid['L5'], n1_wall_list)

# Floors
n1_floor_list = [
    ['C2', 'E2', 'E6', 'C6', 'LIN-HBV-PLANKEN-0.02-0.070-0.200-0.610', 0, 'y'],
    ['E2', 'F2', 'F5', 'E5', 'LIN-HBV-PLANKEN-0.02-0.038-0.138-0.610', 0, 'y'],
    ['E5', 'F5', 'F6', 'E6', 'LIN-HBV-PLANKEN-0.02-0.038-0.138-0.610', 0, 'y'],
    ['F2', 'G2', 'G3', 'F3', 'LIN-HBV-PLANKEN-0.02-0.038-0.138-0.610', 0, 'y'],
    ['F3', 'G3', 'G5', 'F5', 'LIN-HBV-PLANKEN-0.02-0.038-0.138-0.610', 0, 'y'],
    ['F5', 'G5', 'G6', 'F6', 'LIN-HBV-PLANKEN-0.02-0.038-0.138-0.610', 0, 'x'],
    ['A4', 'B4', 'B6', 'A6', 'LIN-HBV-PLANKEN-0.02-0.060-0.110-0.800', 0, 'x'],
    ['B4', 'C4', 'C7', 'A7', 'A6', 'B6', 'LIN-HBV-PLANKEN-0.02-0.060-0.110-0.800', 0, [1, 1, 0]]]
n1_floors = project.viia_create_floors_on_grid(layer='N1', z_coordinate=grid['L4'], floor_list=n1_floor_list)

"""Step 5: Structural Schematisation"""

# Plot walls on this layer to see the ids required for editing the geometry and adding the loads
project.viia_plot_layers(layers='N1', view='2D', shape_types='walls', show=show)

# Plot the entire layer in 3D as well
project.viia_plot_layers(layers='N1', view='3D', show=show)
project.viia_plot_layers(layers=['N0', 'N1'], view='3D', show=show)

"""Step 6: Edit Geometry"""

n1_wall_openings = [
    ['wall_24', [[2.857, 0.750, 0.968, 1.144], [0.43, 0.750, 0.968, 1.144]]]]
project.viia_add_openings(n1_wall_openings)

# =====================================================================================================================
#                                                      LAYER N2
# =====================================================================================================================
"""Step 4: Create Geometry"""

# Walls
n2_wall_list = [['A4', 'A7', 'MW-KLEI<1945', 100],
                ['C4', 'C8', 'MW-KLEI<1945', 100]]
n2_walls = project.viia_create_walls_on_grid('N2', grid['L5'], grid['L6'] + 1, n2_wall_list)

# Floors
n2_floor_list = [['A4', 'C4', 'C7', 'A7', 'LIN-HBV-PLANKEN-0.02-0.060-0.110-0.800', 0, 'y']]
n2_floors = project.viia_create_floors_on_grid('N2', grid['L5'], n2_floor_list)

# Roofs
# Calculate the elevation at the top of the barn
roof_barn = grid['L3'] + (grid['L4'] - grid['L3']) / (grid['H2'][1] - grid['1']) * (0.5 * (grid['1'] + grid['8']))

# Compute equivalent rectangular beam
moi = 0.25 * pi * 0.120 ** 4
b = 0.04
h = round((moi * 12 / b) ** (1 / 3), 2)

# Create barn roofs
roof_1 = project.viia_create_roof(
    name='N2', material=f'LIN-HBV-PLANKEN-0.003-{b}-{h}-0.580', geometry=0, element_x_axis='vertical',
    points=[[
        [*grid['H1', 'L3']],
        [*grid['H2', 'L4']],
        [0.5 * (column_grid['E'] + column_grid['F']), 0.5 * (grid['1'] + grid['8']), roof_barn],
        [grid['C'], 0.5 * (grid['1'] + grid['8']), roof_barn],
        [*grid['C2', 'L4']],
        [*grid['F2', 'L4']],
        [*grid['F1', 'L3']]]])
roof_2 = project.viia_create_roof(
    name='N2', material=f'LIN-HBV-PLANKEN-0.003-{b}-{h}-0.580-4-6.5', geometry=0, element_x_axis='vertical',
    points=[[
        [*grid['H8', 'L3']],
        [grid['H8'][0], grid['H8'][1] - grid['H2'][1], grid['L4']],
        [0.5 * (column_grid['E1'][0] + column_grid['F1'][0]), 0.5 * (grid['H1'][1] + grid['H8'][1]), roof_barn],
        [grid['C1'][0], 0.5 * (grid['C1'][1] + grid['C8'][1]), roof_barn],
        [*grid['C8', 'L3']]]])
roof_3 = project.viia_create_roof(
    name='N2', material=f'LIN-HBV-PLANKEN-0.003-{b}-{h}-0.580', geometry=0, element_x_axis='vertical',
    points=[[
        [*grid['H2', 'L4']],
        [grid['H'], grid['8'] - grid['2'], grid['L4']],
        [0.5 * (column_grid['E'] + column_grid['F']), 0.5 * (grid['1'] + grid['8']), roof_barn]]])

# Create house roofs
factor = 1.778 / sqrt((grid['L6'] - grid['L3']) ** 2 + (0.5 * (grid['4'] + grid['7']) - grid['4']) ** 2)
roof_4 = project.viia_create_roof(
    name='N2', material='LIN-HBV-PLANKEN-0.018-0.050-0.100-1.700', geometry=0, element_x_axis='vertical',
    points=[[
        [*grid['A4', 'L4']],
        [*grid['C4', 'L4']],
        [grid['C'], 0.5 * (grid['4'] + grid['7']), grid['L6']],
        [grid['A'], 0.5 * (grid['4'] + grid['7']), grid['L6']]]])
roof_5 = project.viia_create_roof(
    name='N2', material='LIN-HBV-PLANKEN-0.018-0.050-0.100-1.700', geometry=0, element_x_axis='vertical',
    points=[[
        [*grid['A7', 'L4']],
        [*grid['C7', 'L4']],
        [grid['C'], 0.5 * (grid['4'] + grid['7']), grid['L6']],
        [grid['A'], 0.5 * (grid['4'] + grid['7']), grid['L6']]]])

# Columns
column = project.viia_create_column(
    name='N2',
    material='LIN-HOUT',
    geometry='250x250',
    points=[grid['G7', 'L1'], [*grid['G7'], roof_2]])

# First calculate some relevant values
column_list = \
    ['A2', 'B1', 'C1', 'D1', 'E1', 'F1', 'A3', 'B3', 'C3', 'D3', 'E3', 'F3']
h_columns = \
    grid['L3'] + (roof_barn - grid['L3']) * (grid['H'] - column_grid['F']) / \
    (grid['H'] - 0.5 * (column_grid['E'] + column_grid['F']))
beam_offset = (column_grid['3'] - column_grid['1']) / 3
y_secondary_xbeams_roof = \
    (h_columns - 0.5 * beam_offset - grid['L3']) / (roof_barn - grid['L3']) * 0.5 * (grid['1'] + grid['8'])
beam_offset_2 = \
    grid['H'] - column_grid['F'] - (h_columns - 0.5 * beam_offset - grid['L4']) / (roof_barn - grid['L4']) * \
    (grid['H'] - 0.5 * (column_grid['E'] + column_grid['F']))

# Create the columns supporting the barn roof
# Columns are from ground level to roof
n1_column_list = [
    ['A2', grid['L2'], h_columns, 'LIN-HOUT', '250x250'],
    ['B1', grid['L2'], h_columns, 'LIN-HOUT', '250x250'],
    ['C1', grid['L2'], h_columns, 'LIN-HOUT', '250x250'],
    ['D1', grid['L2'], h_columns, 'LIN-HOUT', '250x250'],
    ['E1', grid['L2'], h_columns, 'LIN-HOUT', '250x250'],
    ['F1', grid['L2'], h_columns, 'LIN-HOUT', '250x250'],
    ['A3', grid['L2'], h_columns, 'LIN-HOUT', '250x250'],
    ['B3', grid['L2'], h_columns, 'LIN-HOUT', '250x250'],
    ['C3', grid['L2'], h_columns, 'LIN-HOUT', '250x250'],
    ['D3', grid['L2'], h_columns, 'LIN-HOUT', '250x250'],
    ['E3', grid['L2'], h_columns, 'LIN-HOUT', '250x250'],
    ['F3', grid['L2'], h_columns, 'LIN-HOUT', '250x250']]
n1_columns = project.viia_create_columns_on_grid(layer='N1', column_list=n1_column_list, grid=column_grid)

# Create beams for the support of the roof

n1_beams_list = [['B1', 'C1', h_columns, 'LIN-HOUT', '300x300'],
                 ['D1', 'E1', h_columns, 'LIN-HOUT', '300x300'],
                 ['B3', 'C3', h_columns, 'LIN-HOUT', '300x300'],
                 ['D3', 'E3', h_columns, 'LIN-HOUT', '300x300']]
n1_beams = project.viia_create_beams_on_grid(layer='N1', beam_list=n1_beams_list, grid=column_grid)

for i in range(len(column_list)):

    # Roof to snap
    if '3' in column_list[i]:
        roof = 'roof_2'
    else:
        roof = 'roof_1'

    # Create first level angled roof beam supports
    project.viia_create_beam(
        name='N2',
        material='LIN-HOUT',
        geometry='110x250',
        points=[[*column_grid[column_list[i]], h_columns - beam_offset],
                [column_grid[column_list[i]][0], column_grid[column_list[i]][1] + beam_offset * (2 * (i < 6) - 1),
                 h_columns]])

    # Create primary angled roof supports (1/2)
    project.viia_create_beam(
        name='N2',
        material='LIN-HOUT',
        geometry='D120',
        points=[[*column_grid[column_list[i]], h_columns - beam_offset],
                [column_grid[column_list[i]][0] - 0.5 * beam_offset, column_grid[column_list[i]][1], roof]])

    # Create primary angled roof supports (2/2)
    if i not in (5, 11):
        project.viia_create_beam(
            name='N2',
            material='LIN-HOUT',
            geometry='D120',
            points=[[*column_grid[column_list[i]], h_columns - beam_offset],
                    [column_grid[column_list[i]][0] + 0.5 * beam_offset, column_grid[column_list[i]][1], roof]])

    # Create secondary angled roof supports (1/3)
    if i not in (0, 4, 11):
        project.viia_create_beam(
            name='N2',
            material='LIN-HOUT',
            geometry='D110',
            points=[[*column_grid[column_list[i]], h_columns - beam_offset],
                    [column_grid[column_list[i]][0], column_grid[column_list[i]][1] - (2 * (i < 6) - 1) * \
                     (column_grid['B1'][1] - y_secondary_xbeams_roof), roof]])

    # Create secondary angled roof supports (2/3)
    if i not in (0, 1, 8, 9, 10, 11):
        project.viia_create_beam(
            name='N2',
            material='LIN-HOUT',
            geometry='D110',
            points=[[*column_grid[column_list[i]], h_columns - beam_offset],
                    [column_grid[column_list[i]][0] - beam_offset_2, column_grid[column_list[i]][1] - (2 * (i < 6) - 1)*\
                     (column_grid['B1'][1] - y_secondary_xbeams_roof), roof]])

    # Create secondary angled roof supports (3/3)
    if i not in (0, 1, 7, 8, 9, 10):
        project.viia_create_beam(
            name='N2',
            material='LIN-HOUT',
            geometry='D110',
            points=[[*column_grid[column_list[i]], h_columns - beam_offset],
                    [column_grid[column_list[i]][0] + beam_offset_2, column_grid[column_list[i]][1] - (2 * (i < 6) - 1)*\
                     (column_grid['B1'][1] - y_secondary_xbeams_roof), roof]])

# Create lower collar ties
gridlines_collar_ties_lower = ['A', 'B', 'C', 'D', 'E', 'F']
project.viia_create_collar_ties_on_grid(
    layer='N2', grid=column_grid, gridlines=gridlines_collar_ties_lower, shapes=[roof_1, roof_2], beam_height=h_columns,
    floor_level=0, material='LIN-HOUT', geometry='300x300')

# Create upper collar ties
n_gridlines = len(collar_tie_grid.gridline_groups[0].gridlines)
gridlines_collar_ties_upper = collar_tie_grid.gridline_groups[0].gridline_names[0:n_gridlines-1]
project.viia_create_collar_ties_on_grid(
    layer='N2', grid=collar_tie_grid, gridlines=gridlines_collar_ties_upper, shapes=[roof_1, roof_2], beam_height=7,
    floor_level=0, material='LIN-HOUT', geometry='D100')

# House rafters and collar ties
n_gridlines = len(house_roof_grid.gridline_groups[0].gridlines)
gridlines_house_roof_beams = house_roof_grid.gridline_groups[0].gridline_names[0:n_gridlines-1]
project.viia_create_beams_on_grid_in_shape(
    layer='N2', grid=house_roof_grid, gridlines=gridlines_house_roof_beams, shape=roof_4, material='LIN-HOUT',
    geometry='65x115')
project.viia_create_beams_on_grid_in_shape(
    layer='N2', grid=house_roof_grid, gridlines=gridlines_house_roof_beams, shape=roof_5, material='LIN-HOUT',
    geometry='65x115')
project.viia_create_collar_ties_on_grid(
    layer='N2', grid=house_roof_grid, gridlines=gridlines_house_roof_beams, shapes=[roof_4, roof_5], beam_height=5.97,
    floor_level=0, material='LIN-HOUT', geometry='65x115')

"""Step 5: Structural Schematisation"""

# Plot layer in 3D
project.viia_plot_layers(layers='N2', view='3D', show=show)
project.viia_plot_layers(layers='N2', view='3D', shape_types=['roofs', 'beams'], show=show)
project.viia_plot_layers(view='3D', show=show)

# Plot with names of wall-shapes and column-shapes
project.viia_plot_layers(layers='N2', view='2D', shape_types=['walls', 'columns'], shape_types_together=True, show=show)

# Plot roofs and beams as well to verify
project.viia_plot_layers(layers='N2', view='2D', shape_types='roofs', show=show)
project.viia_plot_layers(layers='N2', view='2D', shape_types='beams', show=show)

"""Step 6: Edit Geometry"""

# Cut walls using the roofs
n0_walls[0].split_surface(roof_1)
n0_walls[1].split_surface(roof_2)
n0_walls[2].split_surface(roof_2)
n0_walls[3].split_surface(roof_2)
n0_walls[7].split_surface(roof_1)
n0_walls[9].split_surface(roof_5)
n0_walls[13].split_surface(roof_4)
n0_walls[17].split_surface(roof_1)
n1_walls[0].split_surface(roof_1)
n1_walls[0].split_surface(roof_2, keep='largest')
n1_walls[1].split_surface(roof_4, keep='largest')
n1_walls[1].split_surface(roof_5)
n2_walls[1].split_surface(roof_1)
n2_walls[1].split_surface(roof_2)
n2_walls[0].split_surface(roof_4)
n2_walls[0].split_surface(roof_5)

# Cut floor using roof
n2_floors[0].split_surface(roof_4, keep='largest')
n2_floors[0].split_surface(roof_5, keep='largest')

# Perform final cutting using all walls and roofs
for wall in project.collections.walls:
    for roof in [roof_1, roof_2, roof_3]:
        wall.split_surface(roof, keep='largest')

# Create cavity walls and wall ties
cavity_walls = project.viia_create_cavity_wall_ties_from_list(
    ['wall_6',
     ['wall_7', {'wall_tie_distance': 0.5}],
     ['wall_9', {'flip': True}],
     ['wall_10', {'cavity': 0.12, 'flip': True}],
     ['wall_11', {'cavity': 0.12}],
     'wall_18',
     'wall_19',
     'wall_20',
     ['wall_21', {'flip': True}]], cavity=0.07, wall_tie_distance=sqrt(1/2))

# Plot the result
project.viia_plot_layers(view='3D', show=show)

# =====================================================================================================================
#                                                     FOUNDATIONS
# =====================================================================================================================

# Create foundation caps for columns
for i in range(len(column_list)):
    if i != 1:
        fstrip = project.viia_create_fstrip(
            name='F', material='LIN-MW-KLEI<1945', geometry=100,
            points=[[
                [column_grid[column_list[i]][0] - 0.6, column_grid[column_list[i]][1] - 0.6, grid['L1']],
                [column_grid[column_list[i]][0] - 0.6, column_grid[column_list[i]][1] + 0.6, grid['L1']],
                [column_grid[column_list[i]][0] + 0.6, column_grid[column_list[i]][1] + 0.6, grid['L1']],
                [column_grid[column_list[i]][0] + 0.6, column_grid[column_list[i]][1] - 0.6, grid['L1']]]])

# Create foundation strips underneath walls on groundfloor
project.viia_create_foundation_walls_and_strips(
    walls=[n0_walls[i] for i in [0, 1, 2, 4, 5, 6, 8, 9, 10, 11, 12, 13, 13, 15, 17, 18, 19, 20, 21]],
    strip_material='LIN-MW-KLEI<1945',
    strip_width=225,
    strip_thickness=100,
    foundation_depth=grid['L1'],
    adjust_strips=True)

# Columns
# Foundation columns in the barn underneath the columns supporting the roofs
f_column_list = [
    ['A2', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
    ['B1', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
    ['C1', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
    ['D1', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
    ['E1', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
    ['F1', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
    ['A3', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
    ['B3', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
    ['C3', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
    ['D3', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
    ['E3', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600'],
    ['F3', grid['L1'], grid['L2'], 'LIN-HOUT', '600x600']]
f_columns = project.viia_create_columns_on_grid(layer='F', column_list=f_column_list, grid=column_grid)

# =====================================================================================================================
#                                                  NON-SEISMIC LOADS
# =====================================================================================================================
"""Step 7: Apply non-seismic loads"""

"""Permanent Loads"""
# Create the self weight load-case
project.viia_create_loads('Self weight')

# Create the mass of all openings
project.viia_create_mass_all_openings()

# Add loads to sloped roofs
roofs = project.collections.roofs
for roof in roofs:
    project.viia_create_surface_mass_floor(floor=roof, resting_load=['SlopeRoofLoad'])

# Loads from interior wall
project.viia_create_linemass(layer='N1', points=[grid['A6', 'L4'], grid['B6', 'L4']], value=10)

# Imposed floor loads
floors = [floor for floor in project.collections.floors if 'VLOEREN-LIN-HBV' in floor.name] + n0_floors
project.viia_create_loads(load='Imposed load', category='AFloor', connecting_shapes=floors)

# =====================================================================================================================
#                                                   FINALISE MODEL
# =====================================================================================================================
"""Step 7: Finalise the modelscript"""

# Connect all shapes
project.viia_connect_all_shapes()

# Set data properties to all shapes
project.viia_create_all_datas()

# View model in matplot
project.viia_create_plots(show=show)

# Create json-file from model
project.viia_write_dump(project.name + '.json', project.workfolder_location)

# Create pictures for building structural setup appendix
project.viia_create_model_plots()

# Create the building structural setup appendix
project.viia_create_model_plots_appendix()

# =====================================================================================================================
#                                                 END OF MODELSCRIPT
# =====================================================================================================================
